@@ -20,6 +20,7 @@ import gtk
 import os
 import os.path
 import tempfile
+import gobject
 
 # Local imports
 import operations
@@ -46,9 +47,16 @@ class FileDialogComponent (GladeComponent):
         super (FileDialogComponent, self).__init__ (parent)
         
         # Open playlist file dialog
-        self.file_dlg = gtk.FileChooserDialog (buttons = (gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_OPEN,gtk.RESPONSE_OK))
+        self.file_dlg = gtk.FileChooserDialog (
+            parent = self.parent,
+            buttons = (
+                gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
+                gtk.STOCK_OPEN, gtk.RESPONSE_OK
+            )
+        )
         self.file_dlg.set_title ("")
         self.file_dlg.set_transient_for (self.parent)
+        self.file_dlg.set_current_folder (os.path.expanduser("~"))
         self.__file_filters = None
     
     def run_dialog (self, *args):
@@ -127,12 +135,35 @@ class SavePlaylistComponent (GladeComponent):
         )
         self.file_dlg.set_title ("")
         self.file_dlg.set_transient_for (self.parent)
+        self.file_dlg.set_current_folder (os.path.expanduser("~"))
+        hbox = gtk.HBox (spacing = 6)
+        hbox.show ()
+        
+        lbl = gtk.Label(_("Save playlist in format")+":")
+        lbl.show ()
+        hbox.pack_start (lbl, False, False)
+        
+        store = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_STRING)
+        cmb = gtk.ComboBox (store)
+        cmb.show ()
+        cell = gtk.CellRendererText()
+        cmb.pack_start(cell, True)
+        cmb.add_attribute(cell, 'text', 0)
+        self.combo = cmb
+        hbox.pack_start (cmb, False, False)
+
+        self.store = store
+        store.append ((_("Detect by extension"), ""))
+        cmb.set_active (0)
+        
+        self.file_dlg.set_extra_widget (hbox)
         app = self.parent.application
         app.savePlaylist.listeners.append (self)
         self.__sync = True
     
     def on_registred (self, factory, extension, description):
         self.__sync = True
+        self.store.append (("%s (%s)" % (description, extension), extension))
     
     def on_finished (self, evt):
         win = self.parent
@@ -141,13 +172,13 @@ class SavePlaylistComponent (GladeComponent):
             gtkutil.dialog_warn (
                 _("Playlist Saved"),
                 _("Playlist was saved successfully."),
-                win
+                parent = win
             )
         else:
             gtkutil.dialog_error (
                 _("Playlist Not Saved"),
                 _("There was an error while saving the playlist."),
-                win
+                parent = win
             )
         
     def __sync_file_filters (self):
@@ -173,33 +204,41 @@ class SavePlaylistComponent (GladeComponent):
         
         self.__sync_file_filters ()
         
-        if self.file_dlg.run () == gtk.RESPONSE_OK:
+        while self.file_dlg.run () == gtk.RESPONSE_OK:
             filename = self.file_dlg.get_filename ()
             basename = os.path.basename (filename)
+            index = self.combo.get_active ()
+            if index == 0:
+                extension = None
+            else:
+                extension = self.store[index][1]
+                
             if os.path.exists (filename) and gtkutil.dialog_ok_cancel (
                 _("Replace existing file"),
                 _("A file named <i>%s</i> already exists. "
                 "Do you want to replace it with the one "
                 "you are saving?") % basename,
-                win
+                parent = win
             ) != gtk.RESPONSE_OK:
                 
                 self.file_dlg.unselect_all()
                 self.file_dlg.hide()
                 return
-                
+            
             try:
-                oper = app.savePlaylist.save (filename)
+                oper = app.savePlaylist.save (filename, extension)
+                oper.listeners.append (self)
+                oper.start ()
+                break
+
             except SerpentineNotSupportedError:
                 gtkutil.dialog_error (
                     _("Unsupported Format"),
                     _("The playlist format you used (by the file extension) is "
                     "currently not supported."),
-                    win
+                    parent = win
                 )
-            oper.listeners.append (self)
-            oper.start ()
-        
+            
         self.file_dlg.unselect_all()
         self.file_dlg.hide()
 
@@ -379,7 +418,7 @@ class SerpentineWindow (gtk.Window, OperationListener, operations.Operation, Com
                 _("No recording drive found"),
                 _("No recording drive found on your system, therefore some of "
                   "Serpentine's functionalities will be disabled."),
-                self
+                parent = self
             )
             g.get_widget ("preferences_mni").set_sensitive (False)
             self.__write_to_disc.set_sensitive (False)
@@ -458,7 +497,7 @@ class SerpentineWindow (gtk.Window, OperationListener, operations.Operation, Com
             elif err.error_id == SerpentineCacheError.NO_SPACE:
                 title = _("Not enough space on cache directory")
             
-            gtkutil.dialog_warn (title, err.error_message)
+            gtkutil.dialog_warn (title, err.error_message, parent = self)
             return
 
         # TODO: move this to recording module?
@@ -478,7 +517,7 @@ class SerpentineWindow (gtk.Window, OperationListener, operations.Operation, Com
             btn = _("Write to Disc")
             self.__application.preferences.overburn = False
         
-        if gtkutil.dialog_ok_cancel (title, msg, self, btn) != gtk.RESPONSE_OK:
+        if gtkutil.dialog_ok_cancel (title, msg, parent = self, ok_button = btn) != gtk.RESPONSE_OK:
             return
         
         self.application.write_files ().start ()
@@ -487,7 +526,5 @@ class SerpentineWindow (gtk.Window, OperationListener, operations.Operation, Com
     start = gtk.Window.show
 
     def stop (self, *args):
-        evt = operations.FinishedEvent (self, operations.SUCCESSFUL)
-        for listener in self.listeners:
-            listener.on_finished (evt)
+        self._send_finished_event (operations.SUCCESSFUL)
         self.hide ()
