@@ -98,6 +98,7 @@ class RecordingPreferences (object):
                            "preferences_dialog")
         self.__dialog = g.get_widget ("preferences_dialog")
         self.dialog.connect ("destroy-event", self.__on_destroy)
+        self.dialog.set_title ("")
         
         # Drive selection
         drv = g.get_widget ("drive")
@@ -268,7 +269,7 @@ class RecordingPreferences (object):
     
     def getWriteFlags (self):
         ret = self.__write_flags
-        if self.__use_gap.data:
+        if not self.__use_gap.data:
             ret |= nautilusburn.RECORDER_WRITE_DISC_AT_ONCE
         if self.__eject.data:
             ret |= nautilusburn.RECORDER_WRITE_EJECT
