@@ -38,7 +38,7 @@ class ConvertingError:
         gtkutil.dialog_error (
             _("Converting files failed"),
             _("Writing to disc didn't start so it is still usable."),
-            self.win
+            parent = self.win
         )
 
 class WritingError:
@@ -49,13 +49,18 @@ class WritingError:
         if evt.id == operations.SUCCESSFUL:
             return
         
-        gtkutil.dialog_error (
-            evt.id == operations.ERROR and        \
-                      _("Writing to disc failed") or \
-                      _("Writing to disc canceled"),
-            _("The writing operation as started so the disc might be unusable."),
-            self.win
-        )
+        if evt.id == operations.ERROR:
+            title = _("Writing to disc failed")
+        else:
+            title = _("Writing to disc canceled")
+        
+        if evt.error is None:
+            msg = _("The writing operation has started. The disc may "
+                    "be unusable.")
+        else:
+            msg = str (evt.error)
+        
+        gtkutil.dialog_error (title, str(msg), parent = self.win)
 
 ################################################################################
 
@@ -108,7 +113,7 @@ class ConvertAndWrite (MeasurableOperation, OperationsQueueListener):
             gtkutil.dialog_warn (_("CD-RW disc will be erased"),
                                  _("Please remove your disc if you want to "
                                    "preserve it's contents."),
-                                 self.__prog)
+                                 parent = self.__prog)
         self.__blocked = False
         self.preferences.pool.temporaryDir = self.preferences.temporaryDir
         oper = FetchMusicList(self.__music_list, self.preferences.pool)
@@ -122,9 +127,7 @@ class ConvertAndWrite (MeasurableOperation, OperationsQueueListener):
         self.__queue.append (oper)
         
         # Convert a music list into a list of filenames
-        oper = WriteAudioDisc (self.__filenames,
-                                self.preferences,
-                                self.__prog)
+        oper = WriteAudioDisc (self.__filenames, self.preferences, self.__prog)
                                 
         oper.recorder.connect ("progress-changed", self.__tick)
         oper.recorder.connect ("action-changed", self.__on_action_changed)
@@ -184,13 +187,11 @@ class ConvertAndWrite (MeasurableOperation, OperationsQueueListener):
             gtkutil.dialog_warn (
                 _("Writing to disc finished"),
                 _("Disc writing was successful."),
-                self.__prog
+                parent = self.__prog
             )
         
         # Warn our listenrs
-        e = operations.FinishedEvent (self, evt.id)
-        for l in self.listeners:
-            l.on_finished (e)
+        self._propagate (evt)
 
         self.__on_close ()
 
@@ -231,7 +232,15 @@ class WriteAudioDisc (MeasurableOperation):
 
         for filename in self.music_list:
             tracks.append (AudioTrack (filename))
-            
+        
+        if len (tracks) == 0:
+            self._send_finished_event (
+                operations.ERROR,
+                _("There were no valid files for writing. "
+                  "Please select at least one.")
+            )
+            return
+        
         self.recorder.connect ("progress-changed", self.__on_progress)
         self.recorder.connect ("insert-media-request", self.__insert_cd)
         self.recorder.connect ("warn-data-loss", self.__on_data_loss)
@@ -251,11 +260,17 @@ class WriteAudioDisc (MeasurableOperation):
         self.__progress = progress
     
     def __thread (self, tracks):
-        result = self.recorder.write_tracks (self.preferences.drive,
-                                             tracks,
-                                             self.preferences.speedWrite,
-                                             self.preferences.writeFlags)
-
+        error = None
+        try:
+            result = self.recorder.write_tracks (self.preferences.drive,
+                                                 tracks,
+                                                 self.preferences.speedWrite,
+                                                 self.preferences.writeFlags)
+        except gobject.GError, err:
+            result = nautilusburn.RECORDER_RESULT_ERROR
+            # Grab the error message
+            error = str(err)
+            
         if result == nautilusburn.RECORDER_RESULT_FINISHED:
             result = operations.SUCCESSFUL
         elif result == nautilusburn.RECORDER_RESULT_ERROR:
@@ -265,12 +280,8 @@ class WriteAudioDisc (MeasurableOperation):
         elif result == nautilusburn.RECORDER_RESULT_RETRY:
             #TODO: hanlde this
             result == operations.ERROR
-            
-        e = operations.FinishedEvent(self, result)
         
-        self.__running = False
-        for l in self.listeners:
-            l.on_finished (e)
+        self._send_finished_event (result, error)
     
     def __insert_cd (self, rec, reload_media, can_rewrite, busy_cd):
         # messages from nautilus-burner-cd.c
@@ -291,7 +302,7 @@ class WriteAudioDisc (MeasurableOperation):
         else:
             msg = _("Please replace the disc in the drive a blank disc.")
             title = _("Reload blank disc")
-        return gtkutil.dialog_ok_cancel (title, msg, self.parent) == gtk.RESPONSE_OK
+        return gtkutil.dialog_ok_cancel (title, msg, parent = self.parent) == gtk.RESPONSE_OK
 
 
 if __name__ == '__main__':
